..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Installation
============

The Invenio-DB package is on PyPI so all you need is:

.. code-block:: console

    $ pip install invenio-db

Invenio-DB depends on:

| `SQLAlchemy-Utils <https://sqlalchemy-utils.readthedocs.io/en/latest/>`_
| `Flask-SQLAlchemy <https://Flask-SQLAlchemy.readthedocs.io/>`_
| `Flask-Alembic <https://flask-alembic.readthedocs.io/en/latest/>`_
